@@ -595,13 +595,17 @@ casos <- function(datos_covid,
   if (!is.null(edad_cut)) {
     # Obtenemos los grupos de edad
     .casos <- .casos |>
-      dplyr::mutate(!!as.symbol("EDAD_CAT") := cut(!!as.symbol("EDAD"), breaks = edad_cut)) |>
+      dplyr::mutate(!!as.symbol("EDAD_CAT") := cut(!!as.symbol("EDAD"), 
+                                                   breaks = edad_cut, 
+                                                   include.lowest = TRUE)) |>
       dplyr::filter(!is.na(!!as.symbol("EDAD_CAT")))
   }
 
   # Agregamos la entidad a la combinacion si fill zeros
   if (fill_zeros & !is.null(edad_cut)) {
-    .grouping_edad <- dplyr::tibble(EDAD_CAT = cut(edad_cut, breaks = edad_cut)) |>
+    .grouping_edad <- dplyr::tibble(EDAD_CAT = cut(edad_cut, breaks = edad_cut,
+                                                   include.lowest = TRUE)) |>
+      dplyr::distinct() |> #For n = 2, cut repeats the first label so keep only one
       dplyr::filter(!is.na(!!as.symbol("EDAD_CAT")))
 
     if (nrow(.grouping_edad) == 0) {
@@ -686,14 +690,17 @@ casos <- function(datos_covid,
   if (nrow(entidades) > 0 & group_by_entidad) {
     name_join <- c("CLAVE_ENTIDAD")
     names(name_join) <- entidad_tipo
-    .casos <- .casos |> dplyr::left_join(datos_covid$dict[entidad_tipo][[1]], by = name_join)
+    .casos <- .casos |> 
+      dplyr::left_join(datos_covid$dict[entidad_tipo][[1]], by = name_join) |>
+      dplyr::ungroup()
   }
 
   if (length(clasificaciones_finales) > 0 & group_by_tipo_clasificacion) {
     name_join <- c("CLAVE")
     names(name_join) <- "CLASIFICACION_FINAL"
     .casos <- .casos |>
-      dplyr::left_join(datos_covid$dict["CLASIFICACION_FINAL"][[1]][, c(1, 2)], by = name_join)
+      dplyr::left_join(datos_covid$dict["CLASIFICACION_FINAL"][[1]][, c(1, 2)], by = name_join) |>
+      dplyr::ungroup()
   }
 
   if (nrow(pacientes) > 0 & group_by_tipo_paciente) {
@@ -702,7 +709,8 @@ casos <- function(datos_covid,
     paciente_df <- datos_covid$dict["PACIENTE"][[1]]
     colnames(paciente_df) <- c("CLAVE", "DESCRIPCION_TIPO_PACIENTE")
     .casos <- .casos |>
-      dplyr::left_join(paciente_df, by = name_join)
+      dplyr::left_join(paciente_df, by = name_join) |>
+      dplyr::ungroup()
   }
 
   if (nrow(ucis) > 0 & group_by_tipo_uci) {
@@ -711,7 +719,8 @@ casos <- function(datos_covid,
     uci_df <- datos_covid$dict["UCI"][[1]]
     colnames(uci_df) <- c("CLAVE", "DESCRIPCION_TIPO_UCI")
     .casos <- .casos |>
-      dplyr::left_join(uci_df, by = name_join)
+      dplyr::left_join(uci_df, by = name_join) |> 
+      dplyr::ungroup()
   }
 
   if (nrow(sectores) > 0 & group_by_tipo_sector) {
@@ -720,7 +729,8 @@ casos <- function(datos_covid,
     sector_df <- datos_covid$dict["SECTOR"][[1]]
     colnames(sector_df) <- c("CLAVE", "DESCRIPCION_TIPO_SECTOR")
     .casos <- .casos |>
-      dplyr::left_join(sector_df, by = name_join)
+      dplyr::left_join(sector_df, by = name_join) |> 
+      dplyr::ungroup()
   }
 
   .casos <- list(.casos)
